# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['flake8_mypy']
install_requires = \
['attrs', 'flake8>=3.0.0', 'mypy']

setup_kwargs = {
    'name': 'flake8-mypy-fork',
    'version': '20.5.1',
    'description': 'A plugin for flake8 integrating mypy (fork).',
    'long_description': '# flake8-mypy\n\n[![Build Status](https://travis-ci.org/ambv/flake8-mypy.svg?branch=master)](https://travis-ci.org/ambv/flake8-mypy)\n\nA plugin for [Flake8](http://flake8.pycqa.org/) integrating\n[mypy](http://mypy-lang.org/). The idea is to enable limited type\nchecking as a linter inside editors and other tools that already support\n*Flake8* warning syntax and config.\n\n\n## List of warnings\n\n*flake8-mypy* reserves **T4** for all current and future codes, T being\nthe natural letter for typing-related errors.  There are other plugins\ngreedily reserving the entire letter **T**.  To this I say: `\xc2\xaf\\_(\xe3\x83\x84)_/\xc2\xaf`.\n\n**T400**: any typing note.\n\n**T484**: any typing error (after PEP 484, geddit?).\n\n**T498**: internal *mypy* error.\n\n**T499**: internal *mypy* traceback, stderr output, or an unmatched line.\n\nI plan to support more fine-grained error codes for specific *mypy*\nerrors in the future.\n\n\n## Two levels of type checking\n\n*mypy* shines when given a full program to analyze.  You can then use\noptions like `--follow-imports` or `--disallow-untyped-calls` to\nexercise the full transitive closure of your modules, catching errors\nstemming from bad API usage or incompatible types.  That being said,\nthose checks take time, and require access to the entire codebase.  For\nsome tools, like an editor with an open file, or a code review tool,\nachieving this is not trivial.  This is where a more limited approach\ninside a linter comes in.\n\n*Flake8* operates on unrelated files, it doesn\'t perform full program\nanalysis.  In other words, it doesn\'t follow imports.  This is a curse\nand a blessing.  We cannot find complex problems and the number of\nwarnings we can safely show without risking false positives is lower.\nIn return, we can provide useful warnings with great performance, usable\nfor realtime editor integration.\n\nAs it turns out, in this mode of operation, *mypy* is still able to\nprovide useful information on the annotations within and at least usage\nof stubbed standard library and third party libraries.  However, for\nbest effects, you will want to use separate configuration for *mypy*\'s\nstandalone mode and for usage as a *Flake8* plugin.\n\n\n## Configuration\n\nDue to the reasoning above, by default *flake8-mypy* will operate with\noptions equivalent to the following:\n\n```ini\n[mypy]\n# Specify the target platform details in config, so your developers are\n# free to run mypy on Windows, Linux, or macOS and get consistent\n# results.\npython_version=3.6\nplatform=linux\n\n# flake8-mypy expects the two following for sensible formatting\nshow_column_numbers=True\nshow_error_context=False\n\n# do not follow imports (except for ones found in typeshed)\nfollow_imports=skip\n\n# since we\'re ignoring imports, writing .mypy_cache doesn\'t make any sense\ncache_dir=/dev/null\n\n# suppress errors about unsatisfied imports\nignore_missing_imports=True\n\n# allow untyped calls as a consequence of the options above\ndisallow_untyped_calls=False\n\n# allow returning Any as a consequence of the options above\nwarn_return_any=False\n\n# treat Optional per PEP 484\nstrict_optional=True\n\n# ensure all execution paths are returning\nwarn_no_return=True\n\n# lint-style cleanliness for typing needs to be disabled; returns more errors\n# than the full run.\nwarn_redundant_casts=False\nwarn_unused_ignores=False\n\n# The following are off by default since they\'re too noisy.\n# Flip them on if you feel adventurous.\ndisallow_untyped_defs=False\ncheck_untyped_defs=False\n```\n\nIf you disagree with the defaults above, you can specify your own *mypy*\nconfiguration by providing the `--mypy-config=` command-line option to\n*Flake8* (with the .flake8/setup.cfg equivalent being called\n`mypy_config`). The value of that option should be a path to a mypy.ini\nor setup.cfg compatible file.  For full configuration syntax, follow\n[mypy documentation](http://mypy.readthedocs.io/en/latest/config_file.html).\n\nFor the sake of simplicity and readability, the config you provide will\nfully replace the one listed above.  Values left out will be using\n*mypy*\'s own defaults.\n\nRemember that for the best user experience, your linter integration mode\nshouldn\'t generally display errors that a full run of *mypy* wouldn\'t.\nThis would be confusing.\n\nNote: chaing the `follow_imports` option might have surprising effects.\nIf the file you\'re linting with Flake8 has other files around it, then in\n"silent" or "normal" mode those files will be used to follow imports.\nThis includes imports from [typeshed](https://github.com/python/typeshed/).\n\n\n## Tests\n\nJust run:\n\n```\npython setup.py test\n```\n\n## OMG, this is Python 3 only!\n\nYes, so is *mypy*.  Relax, you can run *Flake8* with all popular plugins\n**as a tool** perfectly fine under Python 3.5+ even if you want to\nanalyze Python\xc2\xa02 code.  This way you\'ll be able to parse all of the new\nsyntax supported on Python 3 but also *effectively all* the Python 2\nsyntax at the same time.\n\nBy making the code exclusively Python 3.5+, I\'m able to focus on the\nquality of the checks and re-use all the nice features of the new\nreleases (check out [pathlib](https://docs.python.org/3/library/pathlib.html))\ninstead of wasting cycles on Unicode compatibility, etc.\n\n\n## License\n\nMIT\n\n\n## Change Log\n\n### 17.8.0\n\n* avoid raising errors in the default config which don\'t happen during\n  a full run (disable warn_unused_ignores and warn_redundant_casts)\n\n* always run type checks from a temporary directory to avoid\n  clashing with unrelated files in the same directory\n\n### 17.3.3\n\n* suppress *mypy* messages about relative imports\n\n### 17.3.2\n\n* bugfix: using *Flake8* with absolute paths now correctly matches *mypy*\n  messages\n\n* bugfix: don\'t crash on relative imports in the form `from . import X`\n\n### 17.3.1\n\n* switch `follow_imports` from "silent" to "skip" to avoid name clashing\n  files being used to follow imports within\n  [typeshed](https://github.com/python/typeshed/)\n\n* set MYPYPATH by default to give stubs from typeshed higher priority\n  than local sources\n\n### 17.3.0\n\n* performance optimization: skip running *mypy* over files that contain\n  no annotations or imports from `typing`\n\n* bugfix: when running over an entire directory, T484 is now correctly\n  used instead of T499\n\n### 17.2.0\n\n* first published version\n\n* date-versioned\n\n\n## Authors\n\nGlued together by [\xc5\x81ukasz Langa](mailto:lukasz@langa.pl).\n',
    'author': '\xc5\x81ukasz Langa (original)',
    'author_email': 'lukasz@langa.pl',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'py_modules': modules,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
